==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Zigor Astarbe <zigor@astarbe.com>
 * @author     Adrián Ariza <adrian_ariza.ciudad.com.ar>
 * @author     Gabiel Molina <gabriel191@gmail.com>
 * @author     Paco Avila <monkiki@gmail.com>
 * @author     Bernardo Arlandis Mañó <bernardo@tsolucio.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Editar esta página';
$lang['btn_source'] = 'Ver fuente';
$lang['btn_show']   = 'Ver página';
$lang['btn_create'] = 'Crear esta página';
$lang['btn_search'] = 'Buscar';
$lang['btn_save']   = 'Guardar';
$lang['btn_preview']= 'Previsualización';
$lang['btn_top']    = 'Subir';
$lang['btn_revs']   = 'Revisiones viejas';
$lang['btn_recent'] = 'Cambios recientes';
$lang['btn_upload'] = 'Cargar';
$lang['btn_cancel'] = 'Cancelar';
$lang['btn_index']  = 'Indice';
$lang['btn_secedit']= 'Editar';
$lang['btn_login']  = 'Ingresar';
$lang['btn_logout'] = 'Salir';
$lang['btn_admin']  = 'Administrar';
$lang['btn_update'] = 'Actualizar';
$lang['btn_delete'] = 'Borrar';
$lang['btn_newer']  = '<< más reciente';
$lang['btn_older']  = 'menos reciente >>';
$lang['btn_backtomedia'] = 'Vuelta a la selección de medios';

$lang['loggedinas'] = 'Conectado como ';
$lang['user']       = 'Usuario';
$lang['pass']       = 'Contrasña';
$lang['passchk']    = 'otra vez';
$lang['remember']   = 'Recordarme';
$lang['fullname']   = 'Nombre completo';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registrarse';
$lang['badlogin']   = 'El usuario y la contraseña ingresados son incorrectos.';

$lang['regmissing'] = 'Lo siento, tienes que completar todos los campos.';
$lang['reguexists'] = 'Lo siento, el nombre de usuario ya existe.';
$lang['regsuccess'] = 'El usuario ha sido creado. La contraseña se ha enviado por correo.';
$lang['regsuccess2']= 'El usuario ha sido creado.';
$lang['regmailfail']= 'Parece que ha habido un error al enviar el correo con el password. ¡Por favor, ponte en contacto con el administrador del Wiki!';
$lang['regbadmail'] = 'La dirección de correo no parece válida. Si piensas que esto es un error, ponte en contacto con el administrador del Wiki';
$lang['regbadpass'] = 'Las dos contraseñas no son iguales, por favor prueba de nuevo.';
$lang['regpwmail']  = 'Tu contraseña del DokuWiki';
$lang['reghere']    = '¿No tienes una cuenta todavía?';

$lang['txt_upload'] = 'Selecciona el fichero a cargar';
$lang['txt_filename'] = 'Escribe el wikiname (opcional)';
$lang['txt_overwrt']  = 'Sobreescribe el fichero existente';

$lang['mediaselect'] = 'Selección Mediafile';
$lang['fileupload']  = 'Subida de Mediafile';
$lang['uploadsucc']  = 'Carga satisfactoria';
$lang['uploadfail']  = 'La subida ha fallado. Puede ser por permisos equivocados?';
$lang['mediafiles']  = 'Ficheros disponibles en';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Matching pagenames';
$lang['toc']        = 'Tabla de Contenidos';
$lang['current']    = 'actual';
$lang['diff']       = 'muestra diferencias a la versión actual';
$lang['line']       = 'Línea';
$lang['breadcrumb'] = 'Traza';
$lang['lastmod']    = 'Última modificación';
$lang['by']         = 'por';
$lang['deleted']    = 'borrado';
$lang['created']    = 'creado';
$lang['lockedby']     = 'Actualmente bloqueado por';
$lang['lockexpire']   = 'El bloqueo expira en';
$lang['willexpire']   = 'Tu bloqueo para editar esta página expira en un minuto.\nPara evitar confictos usa el botón previsualizar para reinicial el contador de tiempo.';

$lang['notsavedyet'] = 'Hay cambios que no se han guardado que se perderán.\n¿Quiere continuar?';
$lang['rssfailed']   = 'Se ha producido un error leyendo datos: ';
$lang['nothingfound']= 'No se ha encontrado nada.';

$lang['mail_newpage'] = 'página añadida:';
$lang['mail_changed'] = 'página cambiada:';

$lang['qb_bold']    = 'Texto Negrita';
$lang['qb_italic']  = 'Texto Itálica';
$lang['qb_underl']  = 'Texto Subrayado';
$lang['qb_code']    = 'Texto de Código';
$lang['qb_h1']      = 'Titulo 1';
$lang['qb_h2']      = 'Titulo 2';
$lang['qb_h3']      = 'Titulo 3';
$lang['qb_h4']      = 'Titulo 4';
$lang['qb_h5']      = 'Titulo 5';
$lang['qb_link']    = 'Enlace Interno';
$lang['qb_extlink'] = 'Enlace Externo';
$lang['qb_hr']      = 'Línea horizontal';
$lang['qb_ol']      = 'Item de Lista Ordenada';
$lang['qb_ul']      = 'Item de Lista Desordenada';
$lang['qb_media']   = 'Añadir Imágenes u otros ficheros';

$lang['admin_acl']  = 'Mantenimiento del contol de accesos...';
$lang['admin_register']= 'Añadir nuevo usuario...';

$lang['acl_group']  = 'Grupo';
$lang['acl_user']   = 'Usuario';
$lang['acl_perms']  = 'Permisos para';
$lang['page']       = 'Pagína';
$lang['namespace']  = 'Namespace';
 
$lang['acl_perm1']  = 'Lectura';
$lang['acl_perm2']  = 'Edición';
$lang['acl_perm4']  = 'Crear';
$lang['acl_perm8']  = 'Subir';
$lang['acl_perm16'] = 'Eliminar';
$lang['acl_new']    = 'Añadir nueva entrada';
 
$lang['spell_start'] = 'Comprobar Ortografía';
$lang['spell_stop']  = 'Continuar Edición';
$lang['spell_wait']  = 'Por favor espera...';
$lang['spell_noerr'] = 'No se encontraton errores';
$lang['spell_nosug'] = 'No hay sugerencias';
$lang['spell_change']= 'Cambio';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Zigor Astarbe <zigor@astarbe.com>
 * @author     Adrián Ariza <adrian_ariza.ciudad.com.ar>
 * @author     Gabiel Molina <gabriel191@gmail.com>
 * @author     Paco Avila <monkiki@gmail.com>
 * @author     Bernardo Arlandis Mañó <bernardo@tsolucio.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Editar esta página';
$lang['btn_source'] = 'Ver fuente';
$lang['btn_show']   = 'Ver página';
$lang['btn_create'] = 'Crear esta página';
$lang['btn_search'] = 'Buscar';
$lang['btn_save']   = 'Guardar';
$lang['btn_preview']= 'Previsualización';
$lang['btn_top']    = 'Subir';
$lang['btn_revs']   = 'Revisiones viejas';
$lang['btn_recent'] = 'Cambios recientes';
$lang['btn_upload'] = 'Cargar';
$lang['btn_cancel'] = 'Cancelar';
$lang['btn_index']  = 'Indice';
$lang['btn_secedit']= 'Editar';
$lang['btn_login']  = 'Ingresar';
$lang['btn_logout'] = 'Salir';
$lang['btn_admin']  = 'Administrar';
$lang['btn_update'] = 'Actualizar';
$lang['btn_delete'] = 'Borrar';
$lang['btn_newer']  = '<< más reciente';
$lang['btn_older']  = 'menos reciente >>';
$lang['btn_backtomedia'] = 'Vuelta a la selección de medios';

$lang['loggedinas'] = 'Conectado como ';
$lang['user']       = 'Usuario';
$lang['pass']       = 'Contraseña';
$lang['passchk']    = 'otra vez';
$lang['remember']   = 'Recordarme';
$lang['fullname']   = 'Nombre completo';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registrarse';
$lang['badlogin']   = 'El usuario y la contraseña ingresados son incorrectos.';

$lang['regmissing'] = 'Lo siento, tienes que completar todos los campos.';
$lang['reguexists'] = 'Lo siento, el nombre de usuario ya existe.';
$lang['regsuccess'] = 'El usuario ha sido creado. La contraseña se ha enviado por correo.';
$lang['regsuccess2']= 'El usuario ha sido creado.';
$lang['regmailfail']= 'Parece que ha habido un error al enviar el correo con el password. ¡Por favor, ponte en contacto con el administrador del Wiki!';
$lang['regbadmail'] = 'La dirección de correo no parece válida. Si piensas que esto es un error, ponte en contacto con el administrador del Wiki';
$lang['regbadpass'] = 'Las dos contraseñas no son iguales, por favor prueba de nuevo.';
$lang['regpwmail']  = 'Tu contraseña del DokuWiki';
$lang['reghere']    = '¿No tienes una cuenta todavía?';

$lang['txt_upload'] = 'Selecciona el fichero a cargar';
$lang['txt_filename'] = 'Escribe el wikiname (opcional)';
$lang['txt_overwrt']  = 'Sobreescribe el fichero existente';

$lang['mediaselect'] = 'Selección Mediafile';
$lang['fileupload']  = 'Subida de Mediafile';
$lang['uploadsucc']  = 'Carga satisfactoria';
$lang['uploadfail']  = 'La subida ha fallado. Puede ser por permisos equivocados?';
$lang['mediafiles']  = 'Ficheros disponibles en';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Matching pagenames';
$lang['toc']        = 'Tabla de Contenidos';
$lang['current']    = 'actual';
$lang['diff']       = 'muestra diferencias a la versión actual';
$lang['line']       = 'Línea';
$lang['breadcrumb'] = 'Traza';
$lang['lastmod']    = 'Última modificación';
$lang['by']         = 'por';
$lang['deleted']    = 'borrado';
$lang['created']    = 'creado';
$lang['lockedby']     = 'Actualmente bloqueado por';
$lang['lockexpire']   = 'El bloqueo expira en';
$lang['willexpire']   = 'Tu bloqueo para editar esta página expira en un minuto.\nPara evitar confictos usa el botón previsualizar para reinicial el contador de tiempo.';

$lang['notsavedyet'] = 'Hay cambios que no se han guardado que se perderán.\n¿Quiere continuar?';
$lang['rssfailed']   = 'Se ha producido un error leyendo datos: ';
$lang['nothingfound']= 'No se ha encontrado nada.';

$lang['mail_newpage'] = 'página añadida:';
$lang['mail_changed'] = 'página cambiada:';

$lang['qb_bold']    = 'Texto Negrita';
$lang['qb_italic']  = 'Texto Itálica';
$lang['qb_underl']  = 'Texto Subrayado';
$lang['qb_code']    = 'Texto de Código';
$lang['qb_h1']      = 'Titulo 1';
$lang['qb_h2']      = 'Titulo 2';
$lang['qb_h3']      = 'Titulo 3';
$lang['qb_h4']      = 'Titulo 4';
$lang['qb_h5']      = 'Titulo 5';
$lang['qb_link']    = 'Enlace Interno';
$lang['qb_extlink'] = 'Enlace Externo';
$lang['qb_hr']      = 'Línea horizontal';
$lang['qb_ol']      = 'Item de Lista Ordenada';
$lang['qb_ul']      = 'Item de Lista Desordenada';
$lang['qb_media']   = 'Añadir Imágenes u otros ficheros';

$lang['admin_acl']  = 'Mantenimiento del contol de accesos';
$lang['admin_register']= 'Añadir nuevo usuario...';

$lang['acl_group']  = 'Grupo';
$lang['acl_user']   = 'Usuario';
$lang['acl_perms']  = 'Permisos para';
$lang['page']       = 'Pagína';
$lang['namespace']  = 'Namespace';
 
$lang['acl_perm1']  = 'Lectura';
$lang['acl_perm2']  = 'Edición';
$lang['acl_perm4']  = 'Crear';
$lang['acl_perm8']  = 'Subir';
$lang['acl_perm16'] = 'Eliminar';
$lang['acl_new']    = 'Añadir nueva entrada';
 
$lang['spell_start'] = 'Comprobar Ortografía';
$lang['spell_stop']  = 'Continuar Edición';
$lang['spell_wait']  = 'Por favor espera...';
$lang['spell_noerr'] = 'No se encontraton errores';
$lang['spell_nosug'] = 'No hay sugerencias';
$lang['spell_change']= 'Cambio';

//Setup VIM: ex: et ts=2 enc=utf-8 :
